@@ -36,12 +36,12 @@ mod tests {
             let sport_names = crate::fit_file::init_sport_name_map();
             let sport_id = msg.sport.unwrap();
 
-            println!("Sport: {}", sport_names.get(&sport_id).unwrap());
+            println!("[Sport Message] {}", sport_names.get(&sport_id).unwrap());
         }
         else if global_message_num == crate::fit_file::GLOBAL_MSG_NUM_RECORD {
             let msg = crate::fit_file::FitRecordMsg::new(fields);
 
-            println!("Timestamp: {} Latitude: {} Longitude: {}", timestamp, crate::fit_file::semicircles_to_degrees(msg.position_lat.unwrap()), crate::fit_file::semicircles_to_degrees(msg.position_long.unwrap()));
+            println!("[Record Message] Timestamp: {} Latitude: {} Longitude: {}", timestamp, crate::fit_file::semicircles_to_degrees(msg.position_lat.unwrap()), crate::fit_file::semicircles_to_degrees(msg.position_long.unwrap()));
 
             // Increment the number of records processed.
             let data: &mut Context = unsafe { &mut *(context as *mut Context) };
@@ -49,23 +49,30 @@ mod tests {
         }
         else {
             let global_message_names = crate::fit_file::init_global_msg_name_map();
+            let mut field_num = 1;
 
             match global_message_names.get(&global_message_num) {
-                Some(name) => print!("Callback for {} message, local message type {}, Timestamp {}, Values: ", name, local_msg_type, timestamp),
-                None => print!("Callback for Global Message Num {}, Local Message Type {} Timestamp {}, Values: ", global_message_num, local_msg_type, timestamp)
+                Some(name) => print!("[{} Message Local Message Type {}] Timestamp {}, Values: ", name, local_msg_type, timestamp),
+                None => print!("[Global Message Num {} Local Message Type {}] Timestamp {}, Values: ", global_message_num, local_msg_type, timestamp)
             }
 
             for field in fields {
-                print!("{} ", field.field_def);
+                print!("({}) Type: {}, Value: ", field_num, field.field_def);
 
                 match field.field_type {
                     crate::fit_file::FieldType::FieldTypeNotSet => { print!("[not set] "); },
                     crate::fit_file::FieldType::FieldTypeUInt => { print!("{} ", field.num_uint); },
                     crate::fit_file::FieldType::FieldTypeSInt => { print!("{} ", field.num_sint); },
                     crate::fit_file::FieldType::FieldTypeFloat => { print!("{} ", field.num_float); },
-                    crate::fit_file::FieldType::FieldTypeByteArray => {},
+                    crate::fit_file::FieldType::FieldTypeByteArray => {
+                        for byte in field.byte_array.iter() {
+                            print!("{:#04x} ", byte);
+                        }
+                    },
                     crate::fit_file::FieldType::FieldTypeStr => { print!("\"{}\" ", field.string); },
                 }
+
+                field_num = field_num + 1;
             }
             println!("");
         }
@@ -93,8 +100,11 @@ mod tests {
 
         match fit {
             Ok(fit) => {
+                print!("FIT File Header: ");
                 fit.header.print();
+                println!("");
                 println!("Num records processed: {}", context.num_records_processed);
+                assert!(context.num_records_processed == 1163);
             }
             _ => { println!("Error"); },
         }
@@ -102,7 +112,7 @@ mod tests {
 
     #[test]
     fn file2_bike() {
-        let file = std::fs::File::open("/Users/mike/Code/GitHub/TestFilesForFitnessApps/fit/20130720_run_garmin_forerunner_10.fit").unwrap();
+        let file = std::fs::File::open("tests/20191117_bike_wahoo_elemnt.fit").unwrap();
         let mut reader = std::io::BufReader::new(file);
         let mut context = Context::new();
         let context_ptr: *mut c_void = &mut context as *mut _ as *mut c_void;
@@ -110,8 +120,11 @@ mod tests {
 
         match fit {
             Ok(fit) => {
+                print!("FIT File Header: ");
                 fit.header.print();
+                println!("");
                 println!("Num records processed: {}", context.num_records_processed);
+                assert!(context.num_records_processed == 4876);
             }
             _ => { println!("Error"); },
         }
@@ -127,8 +140,11 @@ mod tests {
 
         match fit {
             Ok(fit) => {
+                print!("FIT File Header: ");
                 fit.header.print();
+                println!("");
                 println!("Num records processed: {}", context.num_records_processed);
+                assert!(context.num_records_processed == 179);
             }
             _ => (),
         }
@@ -183,7 +199,7 @@ mod tests {
         println!("");
         println!("        for field in fields {{");
         println!("            match field.field_def {{");
-        for (field_name, (field_id, field_type)) in field_map {
+        for (field_name, (field_id, field_type)) in field_map.iter() {
             println!("                {} => {{ msg.{} = Some(field.get_{}()); }},", field_id, field_name, *field_type);
         }
         println!("");
